%  This program computes a single realization from the stochastic AK economy
%  Structural parameter values can be changed in the first block of instructions.
%
% [Copyright: J. Ruiz]

nobs = 200;
%
%%   Parameter values
%
beta = 0.97
n = .02
risk = .8
delta = 0.10
A  = .175
phi = 0.50
stdev = .005
%
disp('A+1-d ')
(A+1.0-delta)/(1+n)
disp('beta inverse')
(1+n)/beta
if (A+1-delta)/(1+n) > 1/beta
    disp('Consumption will grow')
else
    disp('Consumption will decrease')
end
%
disp(' Gross rate of growth')
ssgrowth = (beta*(A+1.0-delta)/(1+n))^(1.0/risk)

xss = A + (1.0-delta) - (1+n)*ssgrowth
%
pause;
%
%     Computing the shocks
%
lntheta = [];
innov = randn(nobs,1);
lntheta(1,1) = 0.0;
for i=2:nobs  
lntheta(i,1) = phi*lntheta(i-1,1)+stdev*innov(i,:);
end
theta = exp(lntheta);

%
%      Computing stability
%
gamma0 = [risk/(beta*xss)   -A*(ssgrowth^(-risk))/(1+n) ;
    0.0  1.0 ];
gamma1 = [(risk/(beta*ssgrowth))*((1/(1+n))+(ssgrowth/xss))    -risk*A/((1+n)*beta*ssgrowth) ;
    0.0  phi ];
%
gamma = (inv(gamma0))*gamma1;
[V,D] = eig(gamma) 
invavec = inv(V);
%
%   According to comments in class notes
%
stabilizer = -(gamma1(1,2)-phi*gamma0(1,2))/(gamma1(1,1)-phi*gamma0(1,1))
stabilizer = -invavec(1,2)/invavec(1,1)
%
%       Computing the solution
%
xt = [];
consumption = [];
capital = [];
xt = -invavec(1,2)/invavec(1,1)*lntheta + xss;
capital(1,1) = 100.0;
%   
growth = (A*theta-xt+(1-delta))/(1+n);
%
growthvec = ones(nobs,1).*growth;
cumgrowth = cumprod(growthvec);
for i=1:nobs
    consumption(i,1) = capital(i,1)*xt(i,1); 
    capital(i+1,1) = ((A*theta(i,1)+(1-delta))*capital(i,1)-consumption(i,1))/(1+n);   
end
%
capital = capital(1:nobs,1);
output = A*(theta.*capital);
%
nogrcapital = capital./cumgrowth;
nogrconsumption = consumption./cumgrowth;
nogroutput = output./cumgrowth;
conscap = consumption./capital;
gammak = 100*(log(capital(2:nobs,:))-log(capital(1:nobs-1,:)));
gammac = 100*(log(consumption(2:nobs,:))-log(consumption(1:nobs-1,:)));
%
figure;
hold on
subplot(2,2,1)
plot(nogrconsumption);
title('CONSUMPTION')
xlabel('quarters')
subplot(2,2,2)
plot(nogrcapital);
title('physical capital')
subplot(2,2,3)
plot(conscap);
title('consumption capital ratio')
subplot(2,2,4)
plot(nogroutput);
title('Output')
hold off
pause;
%
figure;
hold on
subplot(2,1,1)
plot(gammac);
title('Growth in consumption')
xlabel('quarters')
subplot(2,1,2)
plot(gammak);
title('Growth in physical capital')
pause;
