numsim = 100;
nobs = 500;
%
%%   Parameter values
%
beta = 0.97
n = .01
risk = .8
delta = 0.10
A  = .15
phi = 0.90
stdev = .005
%
disp('A+1-d ')
(A+1.0-delta)/(1+n)
disp('beta inverse')
(1+n)/beta
if (A+1-delta)/(1+n) > 1/beta
    disp('Consumption will grow')
else
    disp('Consumption will decrease')
end
%
disp(' Gross rate of growth')
growth = (beta*(A+1.0-delta)/(1+n))^(1.0/risk)

xss = A + (1.0-delta) - (1+n)*growth
%
pause;
%
%     Computing the shocks
%
lntheta = [];
innov = randn(nobs,numsim);
lntheta(1,numsim) = 0.0;
for i=2:nobs  
lntheta(i,:) = phi*lntheta(i-1,:)+stdev*innov(i,:);
end
theta = exp(lntheta);

%
%      Computing stability
%
gamma0 = [risk/(beta*xss)   -A*(growth^(-risk))/(1+n) ;
    0.0  1.0 ];
gamma1 = [(risk/(beta*growth))*((1/(1+n))+(growth/xss))    -risk*A/((1+n)*beta*growth) ;
    0.0  phi ];
%
gamma = (inv(gamma0))*gamma1;
[V,D] = eig(gamma) 
invavec = inv(V);
%
%   According to comments in class notes
%
stabilizer = -(gamma1(1,2)-phi*gamma0(1,2))/(gamma1(1,1)-phi*gamma0(1,1))
stabilizer = -invavec(1,2)/invavec(1,1)
%
%       Computing the solution
%
xt = [];
consumption = [];
capital = [];
xt = -invavec(1,2)/invavec(1,1)*lntheta + xss;
capital(1,1:numsim) = 100.0;
%    
growthvec = ones(nobs,1).*growth;
cumgrowth = cumprod(growthvec)*ones(1,numsim);
for i=1:nobs
    consumption(i,:) = capital(i,:).*xt(i,:); 
    capital(i+1,:) = ((A*theta(i,:)+(1-delta)).*capital(i,:)-consumption(i,:))/(1+n);   
end
capital = capital(1:nobs,:);
%
conscap = consumption./capital;
output = A*(theta.*capital);
investment=output-consumption;
nogrcapital = capital./cumgrowth;
nogrconsumption = consumption./cumgrowth;
nogroutput = output./cumgrowth;
nogrinvest=investment./cumgrowth;
gammak = 100*(log(nogrcapital(2:nobs,:))-log(nogrcapital(1:nobs-1,:)));
gammac = 100*(log(nogrconsumption(2:nobs,:))-log(nogrconsumption(1:nobs-1,:)));
gammay = 100*(log(nogroutput(2:nobs,:))-log(nogroutput(1:nobs-1,:)));
gammai = 100*(log(nogrinvest(2:nobs,:))-log(nogrinvest(1:nobs-1,:)));
%
verror=(1/(1+n))*(((1/(1+n))*(conscap(2:nobs,:)./conscap(1:nobs-1,:)).*(A*theta(1:nobs-1,:)-conscap(1:nobs-1,:)+1-delta)).^(-risk)).*(A*theta(2:nobs,:)+1-delta)-(1/beta);
%

Mmean=[];       % matrix of means
Mstd=[];        % matrix of standard desviations 
Mcorr=[];       % matrix of correlations with output 
Mcorr1=[];      % matrix of correlations with output(+1) 
Mcorr2=[];      % matrix of correlations with output(+2) 
Mcorrm1=[];     % matrix of correlations with output(-1) 
Mcorrm2=[];     % matrix of correlations with output(-2)
Merror=[];      % matrix of expectations errors

for j=1:numsim;
    j

       
    lc=log(consumption(1:length(ferror),j));
    lk=log(capital(1:length(ferror),j));
    ly=log(output(1:length(ferror),j));
    li=log(investment(1:length(ferror),j));
    gc=gammac(:,j);
    gk=gammak(:,j);
    gy=gammay(:,j);
    gi=gammai(:,j);
    ferror=verror(:,j);

    % Hodrick&Prescott Filter
    
    %clc=lc-hp(length(lc),100)*lc;
    %clk=lk-hp(length(lc),100)*lk;
    %cly=ly-hp(length(lc),100)*ly;
    %cli=li-hp(length(lc),100)*li;
    %lc=clc;
    %lk=clk;
    %ly=cly;
    %li=cli;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%

    V=[lc lk ly li gc gk gy gi];
    
    T=length(V(:,1));
    
    Mmean=[Mmean; mean(V)];
    Mstd=[Mstd; std(V)];
    
        RHOCY=corrcoef(lc,ly);
        RHOIY=corrcoef(li,ly);
        RHOGCY=corrcoef(gc,gy);
        RHOGKY=corrcoef(gk,gy);
        RHOGIY=corrcoef(gi,gy);
    Mcorr=[Mcorr; RHOCY(1,2) RHOIY(1,2) RHOGCY(1,2)...
         RHOGKY(1,2) RHOGIY(1,2)];   
    
        RHOCY=corrcoef(lc(1:T-1),ly(2:T));
        RHOIY=corrcoef(li(1:T-1),ly(2:T));
        RHOGCY=corrcoef(gc(1:T-1),gy(2:T));
        RHOGKY=corrcoef(gk(1:T-1),gy(2:T));
        RHOGIY=corrcoef(gi(1:T-1),gy(2:T));
    Mcorr1=[Mcorr1; RHOCY(1,2) RHOIY(1,2) RHOGCY(1,2)...
         RHOGKY(1,2) RHOGIY(1,2)];   
        
        RHOCY=corrcoef(lc(1:T-2),ly(3:T));
        RHOIY=corrcoef(li(1:T-2),ly(3:T));
        RHOGCY=corrcoef(gc(1:T-2),gy(3:T));
        RHOGKY=corrcoef(gk(1:T-2),gy(3:T));
        RHOGIY=corrcoef(gi(1:T-2),gy(3:T));
    Mcorr2=[Mcorr2; RHOCY(1,2) RHOIY(1,2) RHOGCY(1,2)...
         RHOGKY(1,2) RHOGIY(1,2)]; 
     
        RHOCY=corrcoef(lc(2:T),ly(1:T-1));
        RHOIY=corrcoef(li(2:T),ly(1:T-1));
        RHOGCY=corrcoef(gc(2:T),gy(1:T-1));
        RHOGKY=corrcoef(gk(2:T),gy(1:T-1));
        RHOGIY=corrcoef(gi(2:T),gy(1:T-1));
    Mcorrm1=[Mcorrm1; RHOCY(1,2) RHOIY(1,2) RHOGCY(1,2)...
         RHOGKY(1,2) RHOGIY(1,2)]; 
     
        RHOCY=corrcoef(lc(3:T),ly(1:T-2));
        RHOIY=corrcoef(li(3:T),ly(1:T-2));
        RHOGCY=corrcoef(gc(3:T),gy(1:T-2));
        RHOGKY=corrcoef(gk(3:T),gy(1:T-2));
        RHOGIY=corrcoef(gi(3:T),gy(1:T-2));
    Mcorrm2=[Mcorrm2; RHOCY(1,2) RHOIY(1,2) RHOGCY(1,2)...
         RHOGKY(1,2) RHOGIY(1,2)]; 
              
        merror=mean(ferror);
        stderror=std(ferror);
        
        perror1=corrcoef(ferror(1:T-1),ferror(2:T));perror1=perror1(1,2);
        perror2=corrcoef(ferror(1:T-2),ferror(3:T));perror2=perror2(1,2);
        perror3=corrcoef(ferror(1:T-3),ferror(4:T));perror3=perror3(1,2);
        perror4=corrcoef(ferror(1:T-4),ferror(5:T));perror4=perror4(1,2);
        perrory=corrcoef(ferror(1:T-1),ly(2:T));perrory=perrory(1,2);
        perrorc=corrcoef(ferror(1:T-1),lc(2:T));perrorc=perrorc(1,2);
        perrork=corrcoef(ferror(1:T-1),lk(2:T));perrork=perrork(1,2);
        perrori=corrcoef(ferror(1:T-1),li(2:T));perrori=perrori(1,2);
    Merror=[Merror; merror stderror perror1 perror2 perror3 perror4 perrory perrorc perrork perrori];     
end

    AVGm=mean(Mmean);
    AVGs=mean(Mstd);
    AVGcorr=mean(Mcorr);
    AVGcor1=mean(Mcorr1);
    AVGcor2=mean(Mcorr2);
    AVGcorm1=mean(Mcorrm1);
    AVGcorm2=mean(Mcorrm2);
    AVGerr=mean(Merror);
    
    STDm=std(Mmean)./(nreal^0.5);
    STDs=std(Mstd)./(nreal^0.5);
    STDcorr=std(Mcorr)./(nreal^0.5);
    STDcor1=std(Mcorr1)./(nreal^0.5);
    STDcor2=std(Mcorr2)./(nreal^0.5);
    STDcorm1=std(Mcorrm1)./(nreal^0.5);
    STDcorm2=std(Mcorrm2)./(nreal^0.5);
    STDerr=std(Merror)./(nreal^0.5);
    
display '__________________________________________________________________________________________________________ '
display 'means and standard desviation of means'
[AVGm;STDm]    
display '      lc       lk         ly        li       gc        gk       gy        gi'

display '__________________________________________________________________________________________________________ '
display 'standard desviations and standard desviation of standard desviations'
[AVGs;STDs]    
display '      lc       lk         ly        li       gc        gk       gy        gi'

display '__________________________________________________________________________________________________________ '
display 'correlations with output and standard desviation of correlations with output'
[AVGcorr;STDcorr]    
display '      lc       li         gc        gk        gi'

display '__________________________________________________________________________________________________________ '
display 'correlations with output(+1) and standard desviation of correlations with output+(1)'
[AVGcor1;STDcor1]    
display '      lc       li        gc        gk        gi'

display '__________________________________________________________________________________________________________ '
display 'correlations with output(+2) and standard desviation of correlations with output(+2)'
[AVGcor2;STDcor2]    
display '      lc       li        gc        gk        gi'

display '__________________________________________________________________________________________________________ '
display 'correlations with output(-1) and standard desviation of correlations with output(-1)'
[AVGcorm1;STDcorm1]    
display '      lc       li        gc        gk        gi'

display '__________________________________________________________________________________________________________ '
display 'correlations with output(-2) and standard desviation of correlations with output(-2)'
[AVGcorm2;STDcorm2]    
display '      lc       li        gc        gk        gi'

display '__________________________________________________________________________________________________________ '
display 'Rationality tests'
[AVGerr;STDerr]    
display '   merror    stderror   perror1   perror2   perror3   perror4   perrory   perrorc   perrork   perrori'


save means.prn AVGm STDm -ascii   
save stds.prn AVGs STDs -ascii
save cvs.prn AVGcv STDcv -ascii
save cys.prn AVGcorr STDcorr -ascii
save cy1s.prn AVGcor1 STDcor1 -ascii
save cy2s.prn AVGcor2 STDcor2 -ascii
save cym1s.prn AVGcorm1 STDcorm1 -ascii
save cym2s.prn AVGcorm2 STDcorm2 -ascii
save errs.prn AVGerr STDerr -ascii


%
figure;
hold on
subplot(2,2,1)
plot(nogrconsumption);
title('CONSUMPTION')
xlabel('quarters')
subplot(2,2,2)
plot(nogrcapital);
title('physical capital')
subplot(2,2,3)
plot(conscap);
title('consumption capital ratio')
subplot(2,2,4)
plot(nogroutput);
title('Output')
hold off
pause;
%
figure;
hold on
subplot(2,1,1)
plot(gammac);
title('Growth in consumption')
xlabel('quarters')
subplot(2,1,2)
plot(gammak);
title('Growth in physical capital')
pause;
%
mgammak = Mmean(:,6);   %mean(gammak);
mgammac = Mmean(:,5);   %mean(gammac);
volk = (Mstd(:,6).^2)';    %var(gammak);
volc = (Mstd(:,5).^2)';    %var(gammac);
%%
for i=1:nobs-1
for j=1:numsim
gammak(i,j) = gammak(i,j)-mgammak(j);
gammac(i,j) = gammac(i,j)-mgammac(j);
end
end
cross = gammak.*gammac;
corrgamma = mean(cross)./(sqrt(volk.*volc));
%
constant = ones(size(nogroutput));
estimation = [];
for i=1:numsim
[bhat,ehat,sigma2,sigbhat,estadt,pvalor,R2] = mco(nogroutput(:,i), [constant(:,i) nogrconsumption(:,i)]);
estim = bhat(2,1);
estimation = [estimation;estim];
end
%
figure;
hist(volk,20);
pause;
hist(volc,20);
pause;
hist(corrgamma,20);
pause;
hist(estimation,20);
pause;



