% Jones and Manuelli / AK models (stochastic version)

% This program computes as many realizations of the numerical solution as
% desired, and provides mean and standard deviations for a number of
% statistics of interest.

% For each of the two Expectations errors in the model, 'Rationality tests' 
% at the end of the program provide its average sample mean and standard 
% deviation over the set of realizations, the average four first values of 
% its autocorrelation function, and average linear correlation coefficient 
% between the expectations error and each of: output, consumption capital stock, and
% real balances

% @Copyright J. Ruiz 2007 

clear

%  structural parameters

A=1.0;              %    technology parameter
B=1.0;              %    technology parameter
beta= 0.95;      	%    discount factor
sigma=3.0;          %    inverse of the intertemporal elasticity of substitution 
                    %    (relative risk aversion)
n=0.01;             %    population growth rate
delta=0.1;          %    depreciation rate
alpha=0.35;         %    capital share
tauc=0.12;          %    consumption tax rate
tauy=0.2;           %    income tax rate
rho=0.95;           %    autoregressive parameter
sigmae=0.01;        %    standard deviation of innovation

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nobs = 300;         % number of observations


paramet=[A,B,beta,sigma,n,delta,alpha,tauc,tauy,rho,sigmae,nobs];


nreal=1000;       % SIMULATIONS  

Mmean=[];       % matrix of means
Mstd=[];        % matrix of standard deviations 
Mcv=[];         % matrix of coefficients of variation 
Mcorr=[];       % matrix of correlations with output 
Mcorr1=[];     % matrix of correlations with output(+1) 
Mcorr2=[];     % matrix of correlations with output(+2) 
Mcorrm1=[];    % matrix of correlations with output(-1) 
Mcorrm2=[];    % matrix of correlations with output(-2)
Merror=[];     % matrix of expectations errors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for j=1:nreal;
    j

    % innovation

        aleatn = normrnd(0,1,nobs+200,1);
        eps = sigmae*aleatn(201:length(aleatn))';
    %%%%%%%%%%%%
    
    V=simulats(paramet,eps);

   
    
    lc=V(:,1);
    lk=V(:,2);
    ly=V(:,3);
    li=V(:,4);
    revy=V(:,5);
    lrev=V(:,6);
    lgc=log(V(:,7));
    lgk=log(V(:,8));
    lgy=log(V(:,9));
    lgi=log(V(:,10));
    ferror=V(:,11);

    % Hodrick&Prescott Filter
    
    clc=lc-hp(length(lc),1600)*lc;
    clk=lk-hp(length(lc),1600)*lk;
    cly=ly-hp(length(lc),1600)*ly;
    cli=li-hp(length(lc),1600)*li;
    clrev=lrev-hp(length(lc),1600)*lrev;
    V(:,1)=clc;
    V(:,2)=clk;
    V(:,3)=cly;
    V(:,4)=cli;
    V(:,6)=clrev;
    lc=clc;
    lk=clk;
    ly=cly;
    lrev=clrev;
    li=cli;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    T=length(V(:,1));
    
    Mmean=[Mmean; mean(V)];
    Mstd=[Mstd; std(V)];
    Mcv=[Mcv; std(V)./mean(V)];
        RHOCY=corrcoef(lc,ly);
        RHOIY=corrcoef(li,ly);
        RHOREVY=corrcoef(lrev,ly);
        RHOGCY=corrcoef(lgc,lgy);
        RHOGKY=corrcoef(lgk,lgy);
        RHOGIY=corrcoef(lgi,lgy);
    Mcorr=[Mcorr; RHOCY(1,2) RHOIY(1,2) RHOREVY(1,2) RHOGCY(1,2)...
         RHOGKY(1,2) RHOGIY(1,2)];   
    
        RHOCY=corrcoef(lc(1:T-1),ly(2:T));
        RHOIY=corrcoef(li(1:T-1),ly(2:T));
        RHOREVY=corrcoef(lrev(1:T-1),ly(2:T));
        RHOGCY=corrcoef(lgc(1:T-1),lgy(2:T));
        RHOGKY=corrcoef(lgk(1:T-1),lgy(2:T));
        RHOGIY=corrcoef(lgi(1:T-1),lgy(2:T));
    Mcorr1=[Mcorr1; RHOCY(1,2) RHOIY(1,2) RHOREVY(1,2) RHOGCY(1,2)...
         RHOGKY(1,2) RHOGIY(1,2)];   
        
        RHOCY=corrcoef(lc(1:T-2),ly(3:T));
        RHOIY=corrcoef(li(1:T-2),ly(3:T));
        RHOREVY=corrcoef(lrev(1:T-2),ly(3:T));
        RHOGCY=corrcoef(lgc(1:T-2),lgy(3:T));
        RHOGKY=corrcoef(lgk(1:T-2),lgy(3:T));
        RHOGIY=corrcoef(lgi(1:T-2),lgy(3:T));
    Mcorr2=[Mcorr2; RHOCY(1,2) RHOIY(1,2) RHOREVY(1,2) RHOGCY(1,2)...
         RHOGKY(1,2) RHOGIY(1,2)]; 
     
        RHOCY=corrcoef(lc(2:T),ly(1:T-1));
        RHOIY=corrcoef(li(2:T),ly(1:T-1));
        RHOREVY=corrcoef(lrev(2:T),ly(1:T-1));
        RHOGCY=corrcoef(lgc(2:T),lgy(1:T-1));
        RHOGKY=corrcoef(lgk(2:T),lgy(1:T-1));
        RHOGIY=corrcoef(lgi(2:T),lgy(1:T-1));
    Mcorrm1=[Mcorrm1; RHOCY(1,2) RHOIY(1,2) RHOREVY(1,2) RHOGCY(1,2)...
         RHOGKY(1,2) RHOGIY(1,2)]; 
     
        RHOCY=corrcoef(lc(3:T),ly(1:T-2));
        RHOIY=corrcoef(li(3:T),ly(1:T-2));
        RHOREVY=corrcoef(lrev(3:T),ly(1:T-2));
        RHOGCY=corrcoef(lgc(3:T),lgy(1:T-2));
        RHOGKY=corrcoef(lgk(3:T),lgy(1:T-2));
        RHOGIY=corrcoef(lgi(3:T),lgy(1:T-2));
    Mcorrm2=[Mcorrm2; RHOCY(1,2) RHOIY(1,2) RHOREVY(1,2) RHOGCY(1,2)...
         RHOGKY(1,2) RHOGIY(1,2)]; 
              
        merror=mean(ferror);
        stderror=std(ferror);
        
        perror1=corrcoef(ferror(1:T-1),ferror(2:T));perror1=perror1(1,2);
        perror2=corrcoef(ferror(1:T-2),ferror(3:T));perror2=perror2(1,2);
        perror3=corrcoef(ferror(1:T-3),ferror(4:T));perror3=perror3(1,2);
        perror4=corrcoef(ferror(1:T-4),ferror(5:T));perror4=perror4(1,2);
        perrory=corrcoef(ferror(1:T-1),ly(2:T));perrory=perrory(1,2);
        perrorc=corrcoef(ferror(1:T-1),lc(2:T));perrorc=perrorc(1,2);
        perrork=corrcoef(ferror(1:T-1),lk(2:T));perrork=perrork(1,2);
        perrori=corrcoef(ferror(1:T-1),li(2:T));perrori=perrori(1,2);
    Merror=[Merror; merror stderror perror1 perror2 perror3 perror4 perrory perrorc perrork perrori];     
end

    AVGm=mean(Mmean);
    AVGs=mean(Mstd);
    AVGcv=mean(Mcv);
    AVGcorr=mean(Mcorr);
    AVGcor1=mean(Mcorr1);
    AVGcor2=mean(Mcorr2);
    AVGcorm1=mean(Mcorrm1);
    AVGcorm2=mean(Mcorrm2);
    AVGerr=mean(Merror);
    
    STDm=std(Mmean)./(nreal^0.5);
    STDs=std(Mstd)./(nreal^0.5);
    STDcv=std(Mcv)./(nreal^0.5);
    STDcorr=std(Mcorr)./(nreal^0.5);
    STDcor1=std(Mcorr1)./(nreal^0.5);
    STDcor2=std(Mcorr2)./(nreal^0.5);
    STDcorm1=std(Mcorrm1)./(nreal^0.5);
    STDcorm2=std(Mcorrm2)./(nreal^0.5);
    STDerr=std(Merror)./(nreal^0.5);
    
display '__________________________________________________________________________________________________________ '
display 'sample means of per-capita variables: means and standard deviations'
[AVGm;STDm]    
display '      lc       lk         ly        li       revy      lrev      gc        gk       gy        gi'

display '__________________________________________________________________________________________________________ '
display 'standard desviations of per-capita variables: means and standard deviations'
[AVGs;STDs]    
display '      lc       lk         ly        li       revy      lrev      gc        gk       gy        gi'

display '__________________________________________________________________________________________________________ '
display 'coefficients of variation of per-capita variables: and standard desviation of coefficients of variations'
[AVGcv;STDcv]    
display '      lc       lk         ly        li       revy      lrev      gc        gk       gy        gi'

display '__________________________________________________________________________________________________________ '
display 'correlations with output: means and standard deviations'
[AVGcorr;STDcorr]    
display '      lc       li        revy       gc        gk        gi'

display '__________________________________________________________________________________________________________ '
display 'correlations with output(+1): means and standard deviations'
[AVGcor1;STDcor1]    
display '      lc       li        revy       gc        gk        gi'

display '__________________________________________________________________________________________________________ '
display 'correlations with output(+2): means and standard deviations'
[AVGcor2;STDcor2]    
display '      lc       li        revy       gc        gk        gi'

display '__________________________________________________________________________________________________________ '
display 'correlations with output(-1): means and standard deviations'
[AVGcorm1;STDcorm1]    
display '      lc       li        revy       gc        gk        gi'

display '__________________________________________________________________________________________________________ '
display 'correlations with output(-2): means and standard deviations'
[AVGcorm2;STDcorm2]    
display '      lc       li        revy       gc        gk        gi'

display '__________________________________________________________________________________________________________ '
display 'Rationality tests'
[AVGerr;STDerr]    
display '   merror    stderror   perror1   perror2   perror3   perror4   perrory   perrorc   perrork   perrori'



save means.prn AVGm STDm -ascii   
save stds.prn AVGs STDs -ascii
save cvs.prn AVGcv STDcv -ascii
save cys.prn AVGcorr STDcorr -ascii
save cy1s.prn AVGcor1 STDcor1 -ascii
save cy2s.prn AVGcor2 STDcor2 -ascii
save cym1s.prn AVGcorm1 STDcorm1 -ascii
save cym2s.prn AVGcorm2 STDcorm2 -ascii
save errs.prn AVGerr STDerr -ascii

    
    