function V=simul2(p,eps1,eps2,error)
%  Simulates the human capital accumulation model under indeterminacy of
%  equilibria

%  @Copyright J. Ruiz 2007 

A=p(1);             %    technology level, final good sector
B=p(2);             %    technology level, educational sector
beta=p(3);          %    discount factor
sigma=p(4);         %    inverse of the intertemporal elasticity of substitution (relative risk aversion)
n=p(5);          	%    population growth rate
deltak=p(6);      	%    depreciation rate of physical capital
deltah=p(7);      	%    depreciation rate of human capital
alpha=p(8);         %    physical capital share (final good sector)
phi1=p(9);          %    persistence parameter of stochastic process for shock in sector of final good
phi2=p(10);         %    persistence parameter of stochastic process for shock in educational sector

psi=p(11);          %    average human capital share (final good sector)

nobs=p(12);         %    number of observations

sigmae1=p(13);      %    standard deviation innovation 1
sigmae2=p(14);      %    standard deviation innovation 2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Parameter values to draw a realization of the forecast error under 
%  indeterminacy of equilibria:
a=p(15);
b=p(16);
sigmae=p(17);
u0=p(18);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Steady state
    gamma=(beta*(B+1-deltah))^((1-alpha+psi)/(sigma*(1-alpha+psi)-psi))-1;
    gammah=(1+gamma)^((1-alpha)/(1-alpha+psi))-1; sigmat=sigma*(1-alpha+psi)/(1-alpha);
    u=1-((gammah+deltah)/B);        
    z=(A*alpha*(u^(1-alpha))/((((1+gamma)^sigma)*(1+n)/beta)-(1-deltak)))^(1/(1-alpha));
    x=A*z^(alpha-1)*u^(1-alpha)+(1-deltak)-(1+n)*(1+gamma);
              param=[A,B,beta,sigma,n,deltak,deltah,alpha,phi1,phi2,psi];
              luss0=log(u);lxss0=log(x);lzss0=log(z);lthetss0=0;letass0=0;
              X0=[lzss0 lzss0 lxss0 lxss0 luss0 luss0 lthetss0 lthetss0 letass0 letass0]';
              X1=fsolve('ssendog',X0,optimset,param);
              lzss=X1(1);zss=exp(lzss);
              lxss=X1(3);xss=exp(lxss);
              luss=X1(5);uss=exp(luss);
    
              J=jacobian('ssendog',X1,param);
                GAMMA0 = -[J(1,1) J(1,3) J(1,5);
                          J(2,1) J(2,3) J(2,5);
                          J(3,1) J(3,3) J(3,5)];
                GAMMA1 = [J(1,2) J(1,4) J(1,6);
                         J(2,2) J(2,4) J(2,6);
                         J(3,2) J(3,4) J(3,6)];
                GAMMA2 = [J(1,8)+phi1*J(1,7) J(1,10)+phi2*J(1,9);
                         J(2,8)+phi1*J(2,7) J(2,10)+phi2*J(2,9);
                         J(3,8)+phi1*J(3,7) J(3,10)+phi2*J(3,9)];
                     
                GAMMA3=inv(GAMMA0)*GAMMA1;
                GAMMA4=inv(GAMMA0)*GAMMA2;
         
    
  [evec,eval]=eig(GAMMA3);
  
  eval2=diag(eval);

  [eval3,ord]=sort(abs(eval2));

  eval4=eval2(ord);

  Lambda=diag(eval4);

  MM=evec(:,ord);

  Mm=inv(MM);
  
  Q=Mm*GAMMA4;
  
  
  S1=[Mm(1,1)-(Mm(1,2)*Mm(3,1))/Mm(3,2)   Mm(1,3)-(Mm(1,2)*Mm(3,3)/Mm(3,2));
      Mm(2,1)-(Mm(2,2)*Mm(3,1))/Mm(3,2)   Mm(2,3)-(Mm(2,2)*Mm(3,3)/Mm(3,2))];
  Lambda1=[Lambda(1,1)  0;
           0            Lambda(2,2)];
  S2=[Q(1,1)+(Q(3,1)/(phi1-Lambda(3,3)))*(Mm(1,2)/Mm(3,2))*(Lambda(1,1)-phi1)   Q(1,2)+(Q(3,2)/(phi2-Lambda(3,3)))*(Mm(1,2)/Mm(3,2))*(Lambda(1,1)-phi2)  Mm(1,3)-(Mm(1,2)*Mm(3,3)/Mm(3,2));
      Q(2,1)+(Q(3,1)/(phi1-Lambda(3,3)))*(Mm(2,2)/Mm(3,2))*(Lambda(2,2)-phi1)   Q(2,2)+(Q(3,2)/(phi2-Lambda(3,3)))*(Mm(2,2)/Mm(3,2))*(Lambda(2,2)-phi2)  Mm(2,3)-(Mm(2,2)*Mm(3,3)/Mm(3,2))];
  
  S3=inv(S1)*Lambda1*S1;
  S4=inv(S1)*S2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Simulations
%  Initial conditions
   htilde0=1;
   ktilde0=z*htilde0;
   z0=ktilde0/htilde0;
   theta0=1;
   eta0=1;
  
%  Shocks
   ltheta=[];leta=[];ltheta0=log(theta0);leta0=log(eta0);
   ltheta=[ltheta;ltheta0];leta=[leta;leta0];
   
   for t=1:nobs
       ltheta1=phi1*ltheta0+eps1(t);
       leta1=phi2*leta0+eps2(t);
       ltheta0=ltheta1;
       leta0=leta1;
       ltheta=[ltheta;ltheta0];leta=[leta;leta0];
   end
   
   % z(t), x(t), u(t)
   estad=[];
   shocks=[ltheta(1:nobs) leta(1:nobs) error]';
   lz0=log(z); lu0=log(u0);
   estad0=[lz0;lu0]; estadss=[log(z); log(u)];
   estad=[estad estad0];
   for t=1:nobs
       estad1=estadss+S3*(estad0-estadss)+S4*shocks(:,t);
       estad0=estad1;
       estad=[estad estad0];
   end
   lz=estad(1,:)';
   lu=estad(2,:)';
   lx=log(x)+(1/Mm(3,2))*((Q(3,1)/(phi1-Lambda(3,3)))*ltheta+...
       (Q(3,2)/(phi2-Lambda(3,3)))*leta-Mm(3,1)*(lz-log(z))-...
       Mm(3,3)*(lu-log(u)));
   
   zt=exp(lz);
   xt=exp(lx);
   ut=exp(lu);
   thetat=exp(ltheta);
   etat=exp(leta);
   
   gammaht=B*(1-ut).*etat-deltah;
   ht=[]; 
   h0=htilde0;
   ht=[ht;h0];  % Detrended stock of human capital 
   for t=1:nobs
       h1=((1+gammaht(t))/(1+gammah))*h0;
       h0=h1;
       ht=[ht;h0];
   end
   kt=ht.*zt;  % Detrended stock of physical capital 
        k0=ktilde0;
   ct=kt.*xt;  % Detrended consumption 
        c0=k0*x;
   gammakt=(1+gamma)*(kt(2:nobs)./kt(1:nobs-1))-1;
   gammact=(1+gamma)*(ct(2:nobs)./ct(1:nobs-1))-1;
   yt=A*(kt.^alpha).*((ut.*ht).^(1-alpha)).*(ht.^psi).*thetat;  % Detrended output 
        y0=A*theta0*k0^alpha*(u*h0)^(1-alpha)*h0^psi;
   gammayt=(1+gamma)*(yt(2:nobs)./yt(1:nobs-1))-1;
   qt=yt+(1-alpha)*A*thetat.*(1-ut).*(ut.^(-alpha)).*(zt.^alpha).*(ht.^(1+psi));  % Detrended gross output 
        q0=y0+(1-alpha)*A*(1-u)*(u^(-alpha))*(z^alpha)*(h0^(1+psi));
   gammaqt=(1+gamma)*(qt(2:nobs)./qt(1:nobs-1))-1;
   prodt=(1-alpha)*yt./(ut.*ht);
        prod=(1-alpha)*A*(z^alpha)*u^(-alpha);
        
   V=[ct(1:nobs-1) kt(1:nobs-1) ht(1:nobs-1) ut(1:nobs-1) yt(1:nobs-1)...
       qt(1:nobs-1) prodt(1:nobs-1) gammaht(1:nobs-1) gammakt(1:nobs-1)...
       gammact(1:nobs-1) gammayt(1:nobs-1) gammaqt(1:nobs-1)]