function V=simulats(p,eps)


A=p(1);             %    technology parameter
B=p(2);             %    technology parameter
beta=p(3);      	%    discount factor
sigma=p(4);         %    inverse of the intertemporal elasticity of substitution 
%                        (relative risk aversion)
n=p(5);             %    population growth rate
delta=p(6);         %    depreciation rate
alpha=p(7);         %    capital share
tauc=p(8);          %    consumption tax rate
tauy=p(9);          %    income tax rate
rho=p(10);          %    autoregressive parameter
sigmae=p(11);       %    standard desviation of innovation

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nobs = p(12);       % number of observations


% steady state

gss = ((beta/(1+n))*((1-tauy)*A+1-delta))^(1/sigma);
ckss = (1/(1+tauc))*((1-tauy)*A+1-delta-(1+n)*gss);
xss = ckss;
ykss = A;  
zss = ykss;
thetass = 1;
kss = 1;

phi1 = beta*(gss^(1-sigma));
phi2 = (sigma*(gss^(sigma-1))-beta*alpha*(gss^(alpha-1)))*...
       (1-tauy)*A*beta*(gss^(1-2*sigma))/((1+n)*sigma);
phi3 = -(beta^2)*((1-tauy)*A/(sigma*(1+n)))*(gss^(1-2*sigma))*...
       (rho-(gss^(alpha-1)));
psi2 = (sigma*(gss^(sigma-1))-beta*rho)*...
       (1-tauy)*A*beta*(gss^(1-2*sigma))/((1+n)*sigma);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

k0 = kss; 
theta0 = thetass; ltheta0=log(theta0);
z0 = theta0*(A+B*k0^(alpha-1));
zc0=log(z0/zss);
if B>0
    xc0=(phi2/(1-phi1*(gss^(alpha-1))))*zc0+ltheta0*...
        (((phi2+phi3)/(1-phi1*rho))-(phi2/(1-phi1*(gss^(alpha-1)))));
end
if B==0
    xc0=psi2*ltheta0/(1-rho*phi1);
end

z=[]; x=[]; lk=[]; lc=[]; ly=[]; li=[]; ktl=[]; ctl=[]; ytl=[]; itl=[];
ltheta=[];

ktl=[ktl;k0]; lk=[lk;log(k0)];
ltheta=[ltheta;ltheta0];
z=[z;z0];

for t=1:nobs
    
    lthetat=rho*ltheta0+eps(t);
    ltheta0=lthetat;
    ltheta=[ltheta;lthetat];
    
    if B>0
        zct=(gss^(alpha-1))*zc0+lthetat;
        zc0=zct;
        zt=zss*exp(zct);
        z=[z;zt];
    
        xct=(phi2/(1-phi1*(gss^(alpha-1))))*zct+lthetat*...
            (((phi2+phi3)/(1-phi1*rho))-(phi2/(1-phi1*(gss^(alpha-1)))));
        xt=xss*exp(xct);
        x=[x;xt];
    end
    if B==0;
        zct=lthetat;
        zt=zss*exp(zct);
        z=[z;zt];
        
        xct=psi2*lthetat/(1-rho*phi1);
        xt=xss*exp(xct);
        x=[x;xt];
    end
        
    ktlt=(((1-tauy)*zt+1-delta-xt*(1+tauc))/(1+n))*k0;
    k0=ktlt;
    ktl=[ktl;ktlt];
    
    lkt=-t*log(gss)+log(ktlt);
    lk=[lk;lkt];
    
    ctlt=ktlt*xt;
    ctl=[ctl;ctlt];
    
    lct=lkt+log(xt);
    lc=[lc;lct];
        
    ytlt=exp(lthetat)*(A*ktlt+B*(ktlt^alpha));
    ytl=[ytl;ytlt];
    
    lyt=log(A*exp(lkt)+B*((gss^(alpha-1))^t)*exp(alpha*lkt))+lthetat;
    ly=[ly;lyt];
end

for t=1:nobs
    itlt=(1+n)*ktl(t+1)-(1-delta)*ktl(t);
    itl=[itl;itlt];
    
    lit=-t*log(gss)+log(itlt);
    li=[li;lit];
end



revy=tauc.*(x./(z(1:length(x)).*exp(ltheta(1:length(x)))))+tauy;
lrev=log(tauc.*exp(lc(1:length(x)))+tauy.*exp(ly(1:length(x))));

gc=ctl(2:length(ctl))./ctl(1:length(ctl)-1);
gk=ktl(2:length(ktl))./ktl(1:length(ktl)-1);
gy=ytl(2:length(ytl))./ytl(1:length(ytl)-1);
gi=itl(2:length(itl))./itl(1:length(itl)-1);

T=length(x);
ferror=(beta/(1+n)).*((x(2:T).^(-sigma)).*((1-tauy)*((1-alpha)*A.*exp(ltheta(2:T))+...
    alpha.*z(2:T))+1-delta))-((1+n).*x(1:T-1)./((1-tauy).*z(1:T-1)+1-delta-(1+tauc).*x(1:T-1))).^(-sigma);

V=[lc(1:length(gi)),lk(1:length(gi)),ly(1:length(gi)),li(1:length(gi)),...
    revy(1:length(gi)),lrev(1:length(gi)),gc(1:length(gi)),gk(1:length(gi)),gy(1:length(gi)),...
    gi(1:length(gi)),ferror(1:length(gi))];
